@@ -724,11 +724,8 @@ class SurfingEntrance(object):
     def pull_hedge_fund_nav(self):
         from .data.manager.manager_fof_lite import FOFDataManagerLite
 
-        MANAGER_ID = 'py1'
-        FOF_ID = 'SLW695'
-
         fof_dm = FOFDataManagerLite()
-        fof_dm.pull_hedge_fund_nav(manager_id=MANAGER_ID, fof_id=FOF_ID)
+        fof_dm.pull_hedge_fund_nav()
 
 
 if __name__ == "__main__":
