@@ -720,13 +720,11 @@ class DerivedDataApi(metaclass=Singleton):
                 print(f'failed to delete data <err_msg> {e} from {FOFNav.__tablename__}')
                 return False
 
-    def get_fof_nav_public(self, manager_id: str, fof_id_list: Tuple[str] = ()):
+    def get_fof_nav_public(self, fof_id_list: Tuple[str] = ()):
         with DerivedDatabaseConnector().managed_session() as session:
             try:
                 query = session.query(
                     FOFNavPublic,
-                ).filter(
-                    FOFNavPublic.manager_id == manager_id,
                 )
                 if fof_id_list:
                     query = query.filter(
