@@ -23,6 +23,7 @@ from ..view.basic_models import FOFInfo, HedgeFundNAV, FOFInvestorPosition, FOFI
 from ..view.derived_models import FOFNav, FOFNavCalc, FOFPosition, FOFInvestorData, FOFPositionDetail
 from ..wrapper.mysql import BasicDatabaseConnector, DerivedDatabaseConnector
 from ..nav_reader.hedge_fund_nav_reader import HedgeFundNAVReader
+from ..nav_reader.fof_nav_reader import FOFNAVReader
 from .manager_hedge_fund import HedgeFundDataManager
 
 
@@ -219,6 +220,7 @@ class FOFDataManagerLite:
 
         positions = self._asset_allocation.loc[self._asset_allocation.event_type.isin([FOFTradeStatus.PURCHASE, FOFTradeStatus.SUBSCRIBE]), :]
         self._water_line_and_confirmed_nav = positions.groupby(by='fund_id', sort=False).apply(_calc_water_line_and_confirmed_nav)
+        # TODO: 这里同一天买同一个产品多次会出错 需要处理一下
         self._total_cost = positions.pivot(index='datetime', columns=['fund_id'], values='amount').sum()
         positions = positions.pivot(index='datetime', columns=['asset_type', 'fund_id'], values='share')
         positions = positions.reindex(index=self._date_list).cumsum().ffill()
@@ -431,7 +433,7 @@ class FOFDataManagerLite:
                         other_assets += row.amount
                         assert row.fund_id in position_details, f'no pos of {row.fund_id} for DIVIDEND_CASH'
                         position_details[row.fund_id]['dividend_cash'] += row.amount
-                assert other_assets >= expenses, f'no enough cash to buy asset!! (date){date} (total cash){total_cash}'
+                # assert other_assets >= expenses, f'no enough cash to buy asset!! (date){date} (total cash){other_assets} (expenses){expenses}'
                 other_assets -= expenses
             except KeyError:
                 pass
@@ -475,7 +477,10 @@ class FOFDataManagerLite:
             if other_assets_list.empty:
                 deposit_interest = 0
             else:
-                deposit_interest = round(other_assets_list.iat[-1] * self._DEPOSIT_INTEREST_PER_YEAR / self._DAYS_PER_YEAR_FOR_INTEREST, 2)
+                if other_assets_list.iat[-1] > 0:
+                    deposit_interest = round(other_assets_list.iat[-1] * self._DEPOSIT_INTEREST_PER_YEAR / self._DAYS_PER_YEAR_FOR_INTEREST, 2)
+                else:
+                    deposit_interest = 0
             deposit_interest_list.loc[date] = deposit_interest
 
             # 计算修正净资产
@@ -672,14 +677,12 @@ class FOFDataManagerLite:
                 df.to_sql(FOFNavCalc.__table__.name, DerivedDatabaseConnector().get_engine(), index=False, if_exists='append')
                 # self._wechat_bot.send_fof_nav_update(df)
                 ret = True
-            fof_nav = self._fof_nav.set_index('datetime').sort_index()
-            fof_nav = fof_nav.nav
-            nav = fof_nav.array[-1]
+            fof_nav_datas = self._fof_nav.set_index('datetime').sort_index()
+            fof_nav = fof_nav_datas.adjusted_nav
             if self._fof_scale is not None and self._fof_redemp is not None:
-                mv = (self._fof_scale.share_changed.sum() - self._fof_redemp.share_changed.sum()) * nav
+                mv = (self._fof_scale.share_changed.sum() - self._fof_redemp.share_changed.sum()) * fof_nav_datas.nav.array[-1]
             else:
                 mv = np.nan
-            total_ret = fof_nav.array[-1] / fof_nav.array[0] - 1
             res_status = Calculator.get_stat_result(fof_nav.index, fof_nav.array)
             print('[dump_fof_nav_and_pos_to_db] dump nav done')
         else:
@@ -793,8 +796,8 @@ class FOFDataManagerLite:
         #                 'start_date': res_status.start_date.isoformat(),
         #                 'days': (fof_nav.index.array[-1] - res_status.start_date).days,
         #                 'mv': mv,
-        #                 'nav': round(nav, 4),
-        #                 'total_ret': f'{round(total_ret * 100, 2)}%',
+        #                 'nav': round(res_status.last_unit_nav, 4),
+        #                 'total_ret': f'{round(res_status.cumu_ret * 100, 2)}%',
         #                 'sharpe': round(res_status.sharpe, 6),
         #                 'annualized_ret': f'{round(res_status.annualized_ret * 100, 2)}%',
         #                 'mdd': f'{round(res_status.mdd * 100, 2)}%',
@@ -809,6 +812,16 @@ class FOFDataManagerLite:
         Session = sessionmaker(BasicDatabaseConnector().get_engine())
         db_session = Session()
         fof_info_to_set = db_session.query(FOFInfo).filter((FOFInfo.manager_id == manager_id) & (FOFInfo.fof_id == fof_id)).one_or_none()
+        # 用托管净值来算以下这些指标 所以这里不用算
+        # fof_info_to_set.latest_cal_date = res_status.end_date
+        # fof_info_to_set.net_asset_value = float(res_status.last_unit_nav) if not pd.isnull(res_status.last_unit_nav) else None
+        # fof_info_to_set.acc_unit_value = float(fof_nav_datas.acc_net_value.array[-1]) if not pd.isnull(fof_nav_datas.acc_net_value.array[-1]) else None
+        # fof_info_to_set.adjusted_net_value = float(fof_nav_datas.adjusted_nav.array[-1]) if not pd.isnull(fof_nav_datas.adjusted_nav.array[-1]) else None
+        # fof_info_to_set.mdd = float(res_status.mdd) if not pd.isnull(res_status.mdd) else None
+        # fof_info_to_set.ret_total = float(res_status.cumu_ret) if not pd.isnull(res_status.cumu_ret) else None
+        # fof_info_to_set.ret_ann = float(res_status.annualized_ret) if not pd.isnull(res_status.annualized_ret) else None
+        fof_info_to_set.total_volume = float(self._total_shares) if not pd.isnull(self._total_shares) else None
+        fof_info_to_set.total_amount = float(self._total_net_assets) if not pd.isnull(self._total_net_assets) else None
         fof_info_to_set.is_calculating = False
         db_session.commit()
         db_session.close()
@@ -869,13 +882,16 @@ class FOFDataManagerLite:
                 Session = sessionmaker(BasicDatabaseConnector().get_engine())
                 db_session = Session()
                 fof_info_to_set = db_session.query(FOFInfo).filter((FOFInfo.manager_id == manager_id) & (FOFInfo.fof_id == fund_id)).one_or_none()
-                fof_info_to_set.latest_cal_date = latest_nav_date
-                fof_info_to_set.net_asset_value = float(fund_nav.nav.array[-1]) if not pd.isnull(fund_nav.nav.array[-1]) else None
+                fof_info_to_set.latest_cal_date = res_status.end_date
+                fof_info_to_set.net_asset_value = float(res_status.last_unit_nav) if not pd.isnull(res_status.last_unit_nav) else None
                 fof_info_to_set.acc_unit_value = float(fund_nav.acc_net_value.array[-1]) if not pd.isnull(fund_nav.acc_net_value.array[-1]) else None
                 fof_info_to_set.adjusted_net_value = float(fund_nav.adjusted_nav.array[-1]) if not pd.isnull(fund_nav.adjusted_nav.array[-1]) else None
                 fof_info_to_set.mdd = float(res_status.mdd) if not pd.isnull(res_status.mdd) else None
-                fof_info_to_set.ret_total = float(total_ret) if not pd.isnull(total_ret) else None
+                fof_info_to_set.ret_total = float(res_status.cumu_ret) if not pd.isnull(res_status.cumu_ret) else None
+                fof_info_to_set.ret_year_to_now = float(res_status.recent_year_ret) if not pd.isnull(res_status.recent_year_ret) else None
                 fof_info_to_set.ret_ann = float(res_status.annualized_ret) if not pd.isnull(res_status.annualized_ret) else None
+                fof_info_to_set.vol = float(res_status.annualized_vol) if not pd.isnull(res_status.annualized_vol) else None
+                fof_info_to_set.sharpe = float(res_status.sharpe) if not pd.isnull(res_status.sharpe) else None
                 db_session.commit()
                 db_session.close()
 
@@ -928,41 +944,62 @@ class FOFDataManagerLite:
                 traceback.print_exc()
                 self._wechat_bot.send_hedge_fund_info_failed(fof_id, fund_id, e)
 
-    def pull_hedge_fund_nav(self, manager_id: str, fof_id: str):
-        import os
+    def pull_hedge_fund_nav(self):
+        # import os
+        import requests
 
-        try:
-            email_data_dir = os.environ['SURFING_EMAIL_DATA_DIR']
-            user_name = os.environ['SURFING_EMAIL_USER_NAME']
-            password = os.environ['SURFING_EMAIL_PASSWORD']
-        except KeyError as e:
-            print(f'[pull_hedge_fund_nav] can not found enough params in env (e){e}')
-            return False
+        # try:
+        #     email_data_dir = os.environ['SURFING_EMAIL_DATA_DIR']
+        #     user_name = os.environ['SURFING_EMAIL_USER_NAME']
+        #     password = os.environ['SURFING_EMAIL_PASSWORD']
+        # except KeyError as e:
+        #     print(f'[pull_hedge_fund_nav] can not found enough params in env (e){e}')
+        #     return False
 
-        hf_nav_r = HedgeFundNAVReader(manager_id, email_data_dir, user_name, password)
-        nav_df: Optional[pd.DataFrame] = hf_nav_r.read_navs_and_dump_to_db()
-        if nav_df is not None:
-            fund_list = list(nav_df.index.unique())
-            # 这里先不用算复权净值了
-            # adj_nav = FOFDataManagerLite._calc_adjusted_net_value(manager_id, fund_list)
-            # adj_nav = adj_nav[adj_nav.ta_factor.notna()]
-            # if not adj_nav.empty:
-            #     print(adj_nav)
-            #     Session = sessionmaker(DerivedDatabaseConnector().get_engine())
-            #     db_session = Session()
-            #     for row in adj_nav.itertuples():
-            #         fof_nav_to_set = db_session.query(FOFNav).filter(FOFNav.manager_id == row.manager_id, FOFNav.fof_id == row.Index, FOFNav.datetime == row.datetime).one_or_none()
-            #         fof_nav_to_set.ta_factor = row.ta_factor
-            #         fof_nav_to_set.adjusted_nav = row.adj_nav
-            #         # fof_nav_to_set.change_rate = row.change_rate
-            #         db_session.commit()
-            #     db_session.close()
-            # TODO: 这里先 hard code 一下
-            if fof_id == 'SLW695':
-                v_nav = FOFDataManagerLite._calc_virtual_net_value(manager_id, fof_id, fund_list)
-            else:
-                v_nav = None
-            self._gather_asset_info_of_fof(manager_id, fof_id, fund_list, v_nav)
+        # hf_nav_r = HedgeFundNAVReader(manager_id, email_data_dir, user_name, password)
+
+        url = 'https://fof.prism-advisor.com/api/v1/manager_mail/email_task'
+        verify_token = 'jisn401f7ac837da42b97f613d789819f37bee6a'
+
+        res = requests.post(
+            url=url,
+            data={
+                'verify_token': verify_token,
+            }
+        )
+        for one in res.json()['data']:
+            print(one)
+            if one['manager_id'] == 'DEMO001':
+                continue
+            fof_nav_r = FOFNAVReader(one)
+            nav_df: Optional[pd.DataFrame] = fof_nav_r.read_navs_and_dump_to_db()
+            if nav_df is not None and not nav_df.empty:
+                # adj_nav = FOFDataManagerLite._calc_adjusted_net_value(one['manager_id'], fund_list)
+                for fof_id in nav_df.fof_id.unique():
+                    fof_nav_df = nav_df[nav_df.fof_id == fof_id]
+                    fof_nav_df = fof_nav_df.set_index('datetime')[['nav', 'acc_net_value']]
+                    fof_others_nav = FOFDataManagerLite.get_fof_nav(one['manager_id'], [fof_id])
+                    fof_others_nav = fof_others_nav[~fof_others_nav.datetime.isin(fof_nav_df.index.array)]
+                    fof_others_nav = fof_others_nav.set_index('datetime')[['nav', 'acc_net_value']]
+                    adj_nav = HedgeFundDataManager.calc_whole_adjusted_net_value(fof_nav_df.append(fof_others_nav).rename(columns={'nav': 'net_asset_value', 'acc_net_value': 'acc_unit_value'}).sort_index())
+                    adj_nav = adj_nav.reindex(fof_nav_df.index.unique())
+                    adj_nav = adj_nav[adj_nav.adj_factor.notna()]
+                    if not adj_nav.empty:
+                        print(adj_nav)
+                        Session = sessionmaker(DerivedDatabaseConnector().get_engine())
+                        db_session = Session()
+                        for row in adj_nav.itertuples():
+                            fof_nav_to_set = db_session.query(FOFNav).filter(FOFNav.manager_id == one['manager_id'], FOFNav.fof_id == fof_id, FOFNav.datetime == row.Index).one_or_none()
+                            fof_nav_to_set.ta_factor = row.adj_factor
+                            fof_nav_to_set.adjusted_nav = row.adj_nav
+                            # fof_nav_to_set.change_rate = row.change_rate
+                            db_session.commit()
+                        db_session.close()
+                fund_list = list(nav_df.fof_id.unique())
+                # TODO: 这里先 hard code 一下
+                if one['fof_id'] == 'SLW695':
+                    v_nav = FOFDataManagerLite._calc_virtual_net_value(one['manager_id'], one['fof_id'], fund_list)
+                    self._gather_asset_info_of_fof(one['manager_id'], one['fof_id'], fund_list, v_nav)
         return True
 
     def calc_all(self, manager_id: str, fof_id: str):
@@ -1576,6 +1613,6 @@ if __name__ == "__main__":
     FOF_ID = 'SLW695'
 
     fof_dm = FOFDataManagerLite()
-    # fof_dm.pull_hedge_fund_nav(manager_id=MANAGER_ID, fof_id=FOF_ID)
+    # fof_dm.pull_hedge_fund_nav()
     fof_dm.calc_fof_nav(manager_id=MANAGER_ID, fof_id=FOF_ID, dump_to_db=True, debug_mode=True)
     # fof_dm.calc_all(manager_id=MANAGER_ID, fof_id=FOF_ID)
