@@ -1,6 +1,6 @@
 
 
-from typing import Optional, List
+from typing import Optional
 # import datetime
 import os
 import traceback
@@ -15,6 +15,8 @@ from ..wrapper.mysql import RawDatabaseConnector
 from ..api.raw import RawDataApi
 from ..api.basic import BasicDataApi
 from ..view.raw_models import HFIndexPrice, HFFundNav
+from ..fund.raw.other_raw_data_downloader import OtherRawDataDownloader
+from ..fund.raw.raw_data_helper import RawDataHelper
 
 
 class ResearchNAVReader:
@@ -40,6 +42,12 @@ class ResearchNAVReader:
                 continue
             try:
                 try:
+                    normal_replace_dict = {
+                        '・': '·',
+                    }
+                    p_name = one.name
+                    for k, v in normal_replace_dict.items():
+                        p_name = p_name.replace(k, v)
                     print(f'[_read_for_NAVData] (name in tar){one.name}')
                 except UnicodeEncodeError:
                     replace_dict = {
@@ -48,13 +56,13 @@ class ResearchNAVReader:
                         '\udcd4Z': '訸',
                         '\udcb6G': '禛',
                         '\udc95D': '旸',
+                        '\udcf1I': '馡',
+                        '\udca9q': '﹒',
                     }
                     p_name = one.name
                     for k, v in replace_dict.items():
                         p_name = p_name.replace(k, v)
                     print(f'[_read_for_NAVData] (name in tar (fixed)){p_name}')
-                else:
-                    p_name = one.name
                 p_name = p_name.split('.')[0]
                 df = pd.read_excel(tar.extractfile(one), na_values=['--'])
                 df = df.rename(columns={'日期': 'datetime', '净值(分红再投)': 'nav'})
@@ -154,6 +162,10 @@ class ResearchNAVReader:
             try:
                 if '净值数据' in name:
                     ResearchNAVReader._read_for_NAVData(file_path)
+
+                    ordd = OtherRawDataDownloader(RawDataHelper())
+                    ret = ordd.hf_fund_nav_miss()
+                    assert not ret, 'update table of hf fund nav miss failed!!'
                 elif '指数数据' in name:
                     update_info = ResearchNAVReader._read_for_IndexData(file_path)
                 else:
