@@ -944,6 +944,10 @@ class FOFInfo(FOFBase):
     benchmark_index = Column(VARCHAR(127))                  # 基准指数
     open_date = Column(CHAR(63))                            # 开放日
     stars = Column(Integer, server_default=text('1'))       # 星级
+    is_structured = Column(BOOLEAN, default=False)          # 是否是分级基金
+    main_fof_id = Column(VARCHAR(32))                       # 主ID
+    last_increase_rate = Column(DOUBLE(asdecimal=False))    # 涨跌幅
+    last_before_date = Column(DATE)                         # 前净值日
 
 
 class FOFScaleAlteration(FOFBase):
