@@ -133,6 +133,9 @@ class IndexValuationLongTerm(Base):
     pb_pct_5_3 = Column(DOUBLE(asdecimal=False)) # PB百分位
     ps_pct_5_3 = Column(DOUBLE(asdecimal=False)) # PS百分位
     roe_pct_5_3 = Column(DOUBLE(asdecimal=False)) # ROE百分位
+    mv = Column(DOUBLE(asdecimal=False)) # 总市值
+    liqmv = Column(DOUBLE(asdecimal=False)) # 流通市值
+    freeliqmv = Column(DOUBLE(asdecimal=False)) # 自由流通市值
 
     __table_args__ = (
         Index('idx_index_valuation_long_term_datetime', 'datetime'),
