@@ -1103,7 +1103,7 @@ class Calculator:
     def index_val_history(begin_date, end_date, time_para, index_id, valuation_type):
         dic = {
             'pb_mrq':'PB',
-            'pe_ttm':'PE',
+            'pe_ttm_nn':'PE',
             'roe':'ROE'
         }
         try:
@@ -1113,6 +1113,7 @@ class Calculator:
             index_val = derived.get_index_valuation_develop(index_ids, begin_date, end_date)
 
             index_val = index_val.rename(columns=dic).set_index('datetime')[[valuation_type]]
+            index_val = index_val.replace(0,np.nan).ffill()
             index_price = BasicDataApi().get_index_price_dt(index_list=index_ids,start_date=begin_date,end_date=end_date)
 
             index_price = index_price.pivot_table(index='datetime',columns='index_id',values='close')
@@ -1368,6 +1369,70 @@ class Calculator:
             res.append({'alpha':alpha,'beta':beta})
             return 1
 
+    @staticmethod
+    def get_product_price_ratio_data(begin_date, end_date, time_para, index_id, fund_id):
+        try:
+            raw = RawDataApi()
+            basic = BasicDataApi()
+            begin_date, end_date = raw.get_date_range(time_para, begin_date, end_date)
+            hf_info = raw.get_hf_fund_info([fund_id])
+            hf_name_dic = hf_info.set_index('fund_id')['desc_name'].to_dict()
+            index_info = basic.get_index_info([index_id])
+            index_name_dic = index_info.set_index('index_id')['desc_name'].to_dict()
+
+            hf_fund_nav = raw.get_hf_fund_nav(fund_ids=[fund_id],start_date=begin_date,end_date=end_date)
+            hf_fund_nav = hf_fund_nav.pivot_table(index='datetime', values='nav', columns='fund_id')
+            index_price = basic.get_index_price_dt(index_list=[index_id],start_date=begin_date,end_date=end_date)
+            index_price = index_price.pivot_table(index='datetime', values='close', columns='index_id')
+            price_df = hf_fund_nav.join(index_price)
+            price_df[index_id] = price_df[index_id].ffill()
+            price_df = price_df.bfill()
+            price_df = price_df/price_df.iloc[0]
+            price_df.loc[:,'price_ratio'] = price_df[fund_id] / price_df[index_id]
+            hf_name_dic.update(index_name_dic)
+            hf_name_dic['price_ratio'] = '价格比'
+            indicator_dics = {
+                'asset_id':'资产名',
+                'cumu_ret':'区间收益',
+                'annualized_ret':'年化收益',
+                'annualized_vol':'年化波动',
+                'mdd':'最大回撤',
+                'sharpe':'夏普比率',
+                'ret_over_mdd':'卡玛比率',
+                'downside_std':'下行风险',
+            }
+            status_dic = []
+            for asset_id in price_df:
+                dates = price_df.index
+                values = price_df[asset_id]
+                dic = Calculator.get_stat_result(dates=dates,values=values,frequency='1W').__dict__
+                dic['asset_id'] = asset_id
+                status_dic.append(dic)
+            df = pandas.DataFrame(status_dic)
+
+            df = df[list(indicator_dics.keys())].rename(columns=indicator_dics)
+            l = ['夏普比率','具体指数','资产名','卡玛比率']
+            for col in df:
+                if col not in l:
+                    df[col] = (df[col] * 100).round(2)
+            df['夏普比率'] = df['夏普比率'].round(2)
+            df['卡玛比率'] = df['卡玛比率'].round(2)
+            df['资产名'] = df.资产名.map(hf_name_dic)
+            price_df = price_df.rename(columns=hf_name_dic)
+            price_df.index.name = 'datetime'
+            data = {
+                '净值':price_df,
+                '指标':df,
+            }
+            return data
+
+        except Exception as e:
+            print(f'Failed to get data <err_msg> {e} from basic.get_product_price_ratio_data')
+            return {
+                '净值':pandas.DataFrame(),
+                '指标':pandas.DataFrame(),
+            }
+
 if __name__ == "__main__":
     # get pct with select rank
     Calculator.get_index_pct_data_df()
