@@ -124,7 +124,7 @@ class CalculatorBase:
         sr_ret = sr_ret.dropna()
         sr_ret.loc[:,'trade_dates'] = sr_ret.apply(lambda x: dts.loc[x.last_day:x.this_day].shape[0], axis=1)
         sr_ret.loc[:,'modify_ret'] = sr_ret.ret / np.sqrt(sr_ret.trade_dates)
-        annual_vol = sr_ret.modify_ret.std(ddof=1) * np.sqrt(CalculatorBase.TRADING_DAYS_PER_YEAR)
+        annual_vol = sr_ret.modify_ret.replace({np.inf:np.nan,-np.inf:np.nan}).std(ddof=1) * np.sqrt(CalculatorBase.TRADING_DAYS_PER_YEAR)
         return annual_vol
 
     @staticmethod
