@@ -123,8 +123,11 @@ class SurfingConfigurator(metaclass=Singleton):
         return settings[key]
 
     def get_wechat_webhook_settings(self, key=None):
-        assert 'wechat_webhook' in self.config, 'could not find wechat_webhook section in config'
-        settings = self.config['wechat_webhook']
+        try:
+            settings = os.environ['SURFING_WECHAT_WEBHOOK']
+        except KeyError:
+            assert 'wechat_webhook' in self.config, 'could not find wechat_webhook section in env and config'
+            settings = self.config['wechat_webhook']
         return settings
 
     def get_cassandra_setting(self):
